#include <vectors.hpp>
#include <math.h>

Vector::Vector()
{
  __Vx = 0.0;
  __Vy = 0.0;
  __Vz = 0.0;
  return;
}

Vector::Vector(double Vx, double Vy, double Vz)
{
  __Vx = Vx;
  __Vy = Vy;
  __Vz = Vz;
  return;
}

double Vector::GetVx() const
{
  return __Vx;
}

double Vector::GetVy() const
{
  return __Vy;
}

double Vector::GetVz() const
{
  return __Vz;
}

void Vector::SetVx(double value)
{
  __Vx = value;
  return;
}

void Vector::SetVy(double value)
{
  __Vy = value;
  return;
}

void Vector::SetVz(double value)
{
  __Vz = value;
  return;
}

double Vector::Modulus()
{
  return sqrt(__Vx*__Vx + __Vy*__Vy + __Vz*__Vz);
}

Vector operator+(Vector& A, Vector& B)
{
  double Ax = A.GetVx();
  double Ay = A.GetVy();
  double Az = A.GetVz();
  double Bx = B.GetVx();
  double By = B.GetVy();
  double Bz = B.GetVz();
  Vector C(Ax + Bx, Ay + By, Az + Bz);
  return C;
}

Vector operator-(Vector& A, Vector& B)
{
  double Ax = A.GetVx();
  double Ay = A.GetVy();
  double Az = A.GetVz();
  double Bx = B.GetVx();
  double By = B.GetVy();
  double Bz = B.GetVz();
  Vector C(Ax - Bx, Ay - By, Az - Bz);
  return C;
}

Vector operator*(Vector& V, double number)
{
  double Vx = V.GetVx();
  double Vy = V.GetVy();
  double Vz = V.GetVz();
  Vector W(Vx * number, Vy * number, Vz * number);
  return W;
}

Vector operator*(double number, Vector& V)
{
  double Vx = V.GetVx();
  double Vy = V.GetVy();
  double Vz = V.GetVz();
  Vector W(Vx * number, Vy * number, Vz * number);
  return W;
}

Vector operator/(Vector& V, double number)
{
  double Vx = V.GetVx();
  double Vy = V.GetVy();
  double Vz = V.GetVz();
  Vector W(Vx / number, Vy / number, Vz / number);
  return W;
}

double operator*(Vector& A, Vector& B)
{
  double Ax = A.GetVx();
  double Ay = A.GetVy();
  double Az = A.GetVz();
  double Bx = B.GetVx();
  double By = B.GetVy();
  double Bz = B.GetVz();
  return Ax * Bx + Ay * By + Az * Bz;
}
 
Vector VectorProduct(Vector& A, Vector& B)
{
  double Ax = A.GetVx();
  double Ay = A.GetVy();
  double Az = A.GetVz();
  double Bx = B.GetVx();
  double By = B.GetVy();
  double Bz = B.GetVz();
  Vector C(Ay*Bz - Az*By, Az*Bx - Ax*Bz, Ax*By - Ay*Bx);
  return C;
}
	     
